<?php
/**
 * This is a test file to examine whether sieve-php.lib can interact with your
 * sieve server properly.
 *
 * Run this script after installing the library.
 *
 * $Id: testsieve.php,v 1.9 2003/11/05 17:34:45 avel Exp $ 
 *
 * Copyright 2001 Dan Ellis <danellis@rushmore.com>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 *
 * @author Dan Ellis
 * @package sieve-php
 */

include "./sieve-php.lib.php";
include "./testsieve_config.php";

/* You should not need to modify anything below this line */

print "<html>";
print "<head>";
print "<title>sieve-php.lib test script</title>";
print "</head>";
print "<body>";
print '<h1><a href="http://sieve-php.sourceforge.net/">sieve-php.lib</a> test script</h1>';

print "<h2>[Step 1]  Trying to login to sieve server:</h2>";

print "Requested authentication types are: $authtypes <br />";
$sieve=new sieve($server, $port, $acctname, $acctpass, $acctname, $authtypes);
if ($sieve->sieve_login()){
    print "Login Successful.<br>";
}
else{
    print "Login Failed! Please check your settings in testsieve_config.php.<br />";
    print "If they are correct, then you should check your SIEVE server setup.<br />";
    print "Also check your server logs.";
    exit;
}


print "<h2>[Step 2]  Verify server information: </h2><br><blockquote>";

print "<p><strong>Server version:</strong> ".$sieve->capabilities["implementation"]."</p>";

print "<p><strong>Server auth types:</strong></p>";
print '<ul>';
while(list($key, $value) = each($sieve->capabilities["auth"]))
  print '<li>'.$key."</li>";
print "</ul>";

print "<p><strong>Server modules:</strong></p>";

print '<ul>';
while(list($key, $value) = each($sieve->capabilities["modules"]))
  print '<li>'.$key."</li>";
print "</ul>";

print "<p><strong>STARTTLS option:</strong></p>";
print '<ul>';
if(isset($sieve->capabilities['starttls']) && $sieve->capabilities['starttls'] == true ) {
  print "<li>Available.</li>";
} else {
  print "<li>Not Available.</li>";
}
print "</ul>";
print "<br>";


if(isset($sieve->capabilities["unknown"])){
    print "<i>--- Unknown server header info:</i>";
    if(is_array($sieve->capabilities["unknown"]))
        foreach($sieve->capabilities["unknown"] as $unk){
            print "-> $unk <br>";
        }
    else
        print "-> ".$sieve->capabilities["unknown"]."<br>";
    print '<br><i>Please report any thing listed above as unknown header info to: '.
	'<a href=mailto:sieve-php-devel@lists.sourceforge.net">sieve-php-devel@lists.sourceforge.net</a></i><P>';
} /* end if */
print "</blockquote>";




print "<h2>[Step 3]  List available scripts for this user: </h2>";
if($sieve->sieve_listscripts()){

    // print "\n<br>RESPONSE: "; print_r($sieve->response);

    if(is_array($sieve->response)) {
        print '<ol>';
        foreach($sieve->response as $result) {
            print '<li>'. $result .'</li>';
	}
	print '</ol>';
    } else {
       print "$result<br>";
    }

    if(isset($sieve->response["ACTIVE"])) {
	$myactivescript=$sieve->response["ACTIVE"];
        print "<p>Active script: <strong>".$myactivescript."</strong></p>";
    }
    else
        print "<p>No active scripts found!</p>>";
}
else
    print "<p>No Scripts found on server!</p>";



print "<h2>[Step 4] Download/Display active script</h2>";

if(isset($myactivescript))  {
   $i=0; 
   $activescript="";
   if($sieve->sieve_getscript($myactivescript)) {
     print '<small><blockquote>';
     if(is_array($sieve->response)) {
       foreach($sieve->response as $result) {
         print ++$i.": $result <br>";
         $activescript .= $result;
       }
     } else {
       print "> $result <br>";
     }
     print '</blockquote></small>';

   } else {
     print "Sieve Error: ".$sieve->error;
   }  
} else
        print "No active scripts found!<br>";



print "<h2>[Step 5] Maniupliate/Upload script</h2>";

if (!isset($activescript) || $activescript == "") {
  print "No active script!  Creating one<P>";
  $activescript = "require \"vacation\";
vacation \"Sorry, I'm away.
I'll read your message when I get around to it.
Thanks.\";
";

} else {
  print "Adding comment to end of existing script.<BR>";
  $activescript .= "/* Adding a comment to end of script */";
}

$testscriptname = "sievephp_testscript";
print "New script name: $testscriptname<br />";

print "New script: <small><pre>\n$activescript\n</pre></small>";

print "<p>Sending $testscriptname...";
if($sieve->sieve_sendscript($testscriptname,$activescript)) {
    print "Upload Succeded.<br>";
} else {
    print "Failed.<br />Error Message:";
    print_r($sieve->error);
    print_r($sieve->error_raw);
}

print "Making script active...";
if($sieve->sieve_setactivescript($testscriptname)) {
    print "Succedded.<br />";
} else {
    print "Failed.<br />Error Message:";
    print_r($sieve->error);
    print_r($sieve->error_raw);
}



print "<h2>[Step 6]  Logging out:</h2>";
if($sieve->sieve_logout()) {
    print "OK<br>";
} else {
    print "Failed.<br />Error Message:";
    print_r($sieve->error);
    print_r($sieve->error_raw);
}

?>
